pub struct ManagedSnipRef {
pub snip_ref: SnipRef,
pub access_policy: ContentAccessPolicy,
}Expand description
A SnipRef is never carried bare in education chain state — it is
always paired with its ContentAccessPolicy. Using this wrapper in
every payload makes a dangling content ref structurally impossible.
Fields
snip_ref: SnipRefaccess_policy: ContentAccessPolicyTrait Implementations
Sourceimpl Clone for ManagedSnipRef
impl Clone for ManagedSnipRef
Sourcefn clone(&self) -> ManagedSnipRef
fn clone(&self) -> ManagedSnipRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ManagedSnipRef
impl Debug for ManagedSnipRef
Sourceimpl<'de> Deserialize<'de> for ManagedSnipRef
impl<'de> Deserialize<'de> for ManagedSnipRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ManagedSnipRef
impl PartialEq for ManagedSnipRef
Sourcefn eq(&self, other: &ManagedSnipRef) -> bool
fn eq(&self, other: &ManagedSnipRef) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ManagedSnipRef
impl Serialize for ManagedSnipRef
impl Eq for ManagedSnipRef
impl StructuralPartialEq for ManagedSnipRef