Module node_registry

Module node_registry 

Node Registry types for SUM Chain.

Defines the on-chain data structures for the node registry, which tracks network nodes beyond validators (e.g. Archive/Storage nodes).

Structs

NodeRecord
On-chain record for a registered node
NodeRegistryTxData
Transaction data for node registry operations
NodeRegistryV2TxData
Transaction data for V2 node registry operations.

Enums

NodeRegistryOperation
Operations that can be performed on the node registry
NodeRegistryOperationV2
V2 node registry operations. Additive — V1 NodeRegistryOperation is unchanged.
NodeRole
Role a node can play in the network
NodeStatus
Status of a registered node