pub struct ValidatorSet {
pub epoch: u64,
pub active_from: BlockHeight,
pub validators: Vec<ValidatorSetEntry>,
pub total_voting_power: Balance,
pub proposer_seed: [u8; 32],
}Expand description
The active validator set for an epoch
Fields
epoch: u64The epoch this validator set is for
active_from: BlockHeightBlock height when this set became active
validators: Vec<ValidatorSetEntry>List of validators sorted by voting power (descending)
total_voting_power: BalanceTotal voting power in this set
proposer_seed: [u8; 32]Proposer selection seed (hash of previous epoch’s last block)
Implementations
Sourceimpl ValidatorSet
impl ValidatorSet
Sourcepub fn new(
epoch: u64,
active_from: BlockHeight,
validators: Vec<ValidatorSetEntry>,
proposer_seed: [u8; 32],
) -> Self
pub fn new( epoch: u64, active_from: BlockHeight, validators: Vec<ValidatorSetEntry>, proposer_seed: [u8; 32], ) -> Self
Create a new validator set
Sourcepub fn get(&self, pubkey: &[u8; 32]) -> Option<&ValidatorSetEntry>
pub fn get(&self, pubkey: &[u8; 32]) -> Option<&ValidatorSetEntry>
Get a validator’s entry by pubkey
Sourcepub fn get_stake_weighted_proposer(
&self,
height: BlockHeight,
) -> Option<[u8; 32]>
pub fn get_stake_weighted_proposer( &self, height: BlockHeight, ) -> Option<[u8; 32]>
Get the proposer for a given height using stake-weighted selection
Sourcepub fn get_round_robin_proposer(&self, height: BlockHeight) -> Option<[u8; 32]>
pub fn get_round_robin_proposer(&self, height: BlockHeight) -> Option<[u8; 32]>
Get the proposer for a given height using round-robin selection
Sourcepub fn voting_power(&self, pubkey: &[u8; 32]) -> Balance
pub fn voting_power(&self, pubkey: &[u8; 32]) -> Balance
Get the voting power for a validator
Sourcepub fn voting_power_percentage(&self, pubkey: &[u8; 32]) -> u16
pub fn voting_power_percentage(&self, pubkey: &[u8; 32]) -> u16
Calculate the voting power percentage for a validator (in basis points)