TransactionV2

Struct TransactionV2 

pub struct TransactionV2 {
    pub chain_id: ChainId,
    pub from: Address,
    pub fee: Balance,
    pub nonce: Nonce,
    pub payload: TxPayload,
}
Extended transaction with payload type

Fields

chain_id: ChainId

Chain ID to prevent replay across networks

from: Address

Sender address

fee: Balance

Transaction fee paid to validator

nonce: Nonce

Sender’s nonce (must match account nonce)

payload: TxPayload

Transaction payload

Implementations

Source

impl TransactionV2

pub fn transfer( chain_id: ChainId, from: Address, to: Address, amount: Balance, fee: Balance, nonce: Nonce, ) -> Self

Create a new transfer transaction

pub fn nft( chain_id: ChainId, from: Address, fee: Balance, nonce: Nonce, nft_data: NftTxData, ) -> Self

Create a new NFT transaction

pub fn token( chain_id: ChainId, from: Address, fee: Balance, nonce: Nonce, token_data: TokenTxData, ) -> Self

Create a new Token (SRC-20) transaction

pub fn contract_deploy( chain_id: ChainId, from: Address, fee: Balance, nonce: Nonce, deploy_data: ContractDeployData, ) -> Self

Create a new contract deployment transaction

pub fn contract_call( chain_id: ChainId, from: Address, fee: Balance, nonce: Nonce, call_data: ContractCallData, ) -> Self

Create a new contract call transaction

pub fn staking( chain_id: ChainId, from: Address, fee: Balance, nonce: Nonce, staking_data: StakingTxData, ) -> Self

Create a new staking transaction

pub fn messaging( chain_id: ChainId, from: Address, fee: Balance, nonce: Nonce, messaging_data: MessagingTxData, ) -> Self

Create a new messaging transaction

pub fn tx_type(&self) -> TxType

Get the transaction type

pub fn signing_hash(&self) -> Hash

Compute the signing hash

pub fn to_bytes(&self) -> Vec<u8>

Serialize to bytes

pub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>

Deserialize from bytes

pub fn recipient(&self) -> Option<Address>

Get recipient address (for transfers) or contract address (for calls)

pub fn amount(&self) -> Balance

Get transfer amount (for transfers) or value (for contract calls)

pub fn to_legacy(&self) -> Option<Transaction>

Convert to legacy Transaction format (only for transfers)

pub fn deploy_data(&self) -> Option<&ContractDeployData>

Get contract deploy data if this is a deploy transaction

pub fn call_data(&self) -> Option<&ContractCallData>

Get contract call data if this is a call transaction

pub fn is_contract(&self) -> bool

Check if this is a contract transaction

pub fn token_data(&self) -> Option<&TokenTxData>

Get token data if this is a Token transaction

pub fn staking_data(&self) -> Option<&StakingTxData>

Get staking data if this is a Staking transaction

pub fn is_staking(&self) -> bool

Check if this is a staking transaction

pub fn messaging_data(&self) -> Option<&MessagingTxData>

Get messaging data if this is a Messaging transaction

pub fn is_messaging(&self) -> bool

Check if this is a messaging transaction

pub fn docclass_data(&self) -> Option<&DocClassTxData>

Get docclass data if this is a DocClass transaction

pub fn is_docclass(&self) -> bool

Check if this is a docclass transaction