Node Registry types for SUM Chain.
Defines the on-chain data structures for the node registry, which tracks network nodes beyond validators (e.g. Archive/Storage nodes).
Structs
- Node
Record - On-chain record for a registered node
- Node
Registry TxData - Transaction data for node registry operations
- Node
Registry V2Tx Data - Transaction data for V2 node registry operations.
Enums
- Node
Registry Operation - Operations that can be performed on the node registry
- Node
Registry Operation V2 - V2 node registry operations. Additive — V1
NodeRegistryOperationis unchanged. - Node
Role - Role a node can play in the network
- Node
Status - Status of a registered node